Module config

Module config 

Functions

create_indexes
Utility function to create indexes by providing the collection, the indexes to be created and whatever index options you need.
db_client
Get a database client by providing a database connection string
init_db
Get a database instance by providing a database connection string and the database name