create_indexes

Function create_indexes 

pub async fn create_indexes<T: BaseDocument>(
    collection: Collection<T>,
    indexes: Vec<IndexModel>,
    options: Option<CreateIndexOptions>,
)
Utility function to create indexes by providing the collection, the indexes to be created and whatever index options you need.