Module pageable
mongo_
data
2.0.0
Module pageable
Module Items
Structs
In mongo_
data::
document
mongo_data
::
document
Module
pageable
Structs

Pageable
Request
Utility struct to represent pageable requests to the database
Pageable
Response
Utility struct to represent pageable response from the database