pub async fn create_indexes<T: BaseDocument>(
collection: Collection<T>,
indexes: Vec<IndexModel>,
options: Option<CreateIndexOptions>,
)Expand description
Utility function to create indexes by providing the collection, the indexes to be created and whatever index options you need.