Module pageable

Module pageable 

Structs

PageableRequest
Utility struct to represent pageable requests to the database
PageableResponse
Utility struct to represent pageable response from the database